@@ -39,7 +39,6 @@ sub arguments {
         $arguments->{$pk}{'render_as'} = 'Unrendered'; 
         # primary key fields should always be hidden fields
     }
-    $arguments->{delete} = {render_as => "Unrendered"};
     return $arguments;
 }
 
@@ -110,15 +109,6 @@ sub take_action {
         $changed = 1 if $val;
     }
 
-    # XXX: This should be only on ::Delete 
-    if ($self->argument_value("delete")) {
-        my ( $val, $msg ) = $self->record->delete;
-        $self->result->error($msg)
-          if not $val and $msg;
-
-        $changed = 1 if $val;
-    }
-
     $self->report_success
       if $changed and not $self->result->failure;
 
