@@ -192,11 +192,6 @@ Returns the message as a scalar.
 
 =cut
 
-sub preface {
-    my $self = shift;
-
-    return '';
-}
 
 
 =head2 footer
@@ -207,10 +202,6 @@ Returns the message as a scalar.
 
 =cut
 
-sub footer {
-    return undef;
-}
-
 
 =head2 magic_letme_token_for PATH
 
